//
//  BFVideoThumbProgressView.swift
//  BFRecordScreenKit
//
//  Created by 胡志强 on 2021/12/3.
//

import Foundation
import UIKit
import AVFoundation
import BFCommonKit
import SnapKit

class BFVideoThumbProgressView: UIView {
    var videoAsset : AVURLAsset? {
        didSet{
            if let videoAsset = videoAsset {
                let dur = videoAsset.duration.seconds
                if dur > 0{
                    let fps = Double(fetchThumbStrategy.frameNumberOfVideo(assetDuration: dur)) / dur
                    
                    splitVideoFileUrlFps(urlAsset: videoAsset, fps: fps) {[weak self] images in
                        if images.count > 0{
                            self?.thumbImgs = images
                            DispatchQueue.main.async {[weak self] in
                                if let sself = self{
                                    for (i, img) in images.enumerated() {
                                        let iv = UIImageView(image: img)
                                        iv.contentMode = .scaleAspectFill
                                        iv.clipsToBounds = true
                                        sself.progressView.addSubview(iv)
                                        iv.snp.makeConstraints { make in
//                                            make.left.equalTo(CGFloat(i) * sself.thumbImageWidth + sself.width * 0.5)
                                            make.top.height.equalToSuperview()
                                            make.width.equalTo(sself.thumbImageWidth)
                                        }
                                    }
//                                    sself.progressView.contentSize = CGSize(width: CGFloat(images.count) *  sself.thumbImageWidth + sself.width, height: sself.height)
                                }
                            }
                        }
                    }
                    
                }
            }
        }
    }
    
    var dragScrollProgressHandle : ((Float) -> Void)?
    var dragEndHandle : ((Float) -> Void)?
    var isDrag = false
    
    let thumbImageWidth = 70.0
    
    let fetchThumbStrategy : BFVideoThumbProgressStrategyProtocol = BFVideoThumbProgressStrategy()
    
    var progress:Double = 0 {
        didSet{
            if let second = self.videoAsset?.duration.seconds, second > 0 {
                let w = progressView.contentSize.width - width
//                progressView.contentOffset = CGPoint(x: progress * w / second, y: 0)
            }
        }
    }
    
    var thumbImgs = [UIImage]()
    
    lazy var progressView : UIScrollView = {
        let sv = UIScrollView()
        sv.bounces = false
        sv.backgroundColor = .clear
        sv.decelerationRate = .fast
        sv.showsHorizontalScrollIndicator = false
        sv.delegate = self
        
        return sv
    }()

    override init(frame: CGRect) {
        super.init(frame: frame)
        addSubview(progressView)
        
        let line = UIView()
        line.backgroundColor = .white
        line.layer.shadowColor = UIColor.black.cgColor
        line.layer.shadowOffset = CGSize(width: 1, height: 1)
        addSubview(line)
        line.snp.makeConstraints { make in
            make.width.equalTo(2)
            make.center.height.equalToSuperview()
        }
        
    }

    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func layoutSubviews() {
        super.layoutSubviews()
        progressView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
    }
}

extension BFVideoThumbProgressView : UIScrollViewDelegate {
    func scrollViewDidScroll(_ scrollView: UIScrollView) {
        if isDrag{
            let dur = scrollView.contentOffset.x / (scrollView.contentSize.width - self.width)
            self.dragScrollProgressHandle?(Float(dur))
        }
    }
    
    func scrollViewWillBeginDragging(_ scrollView: UIScrollView) {
        isDrag = true
        let dur = scrollView.contentOffset.x / (scrollView.contentSize.width - self.width)
        self.dragScrollProgressHandle?(Float(dur))
    }
    
    func scrollViewDidEndDragging(_ scrollView: UIScrollView, willDecelerate decelerate: Bool) {
        if !decelerate {
            let dur = scrollView.contentOffset.x / (scrollView.contentSize.width - self.width)
            isDrag = false
            dragEndHandle?(Float(dur))
        }
    }
    
    func scrollViewDidEndDecelerating(_ scrollView: UIScrollView) {
        let dur = scrollView.contentOffset.x / (scrollView.contentSize.width - self.width)
        isDrag = false
        dragEndHandle?(Float(dur))

    }
    
}
